==> cohesity_management_sdk-1.5.0.tar.gz: cohesity_management_sdk-1.5.0/cohesity_management_sdk/models/stopped_service_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Cohesity Inc.

class StoppedServiceEnum(object):

    """Implementation of the 'StoppedService' enum.

    TODO: type enum description here.

    Attributes:
        KAPOLLO: TODO: type description here.
        KBRIDGE: TODO: type description here.
        KGENIE: TODO: type description here.
        KGENIEGOFER: TODO: type description here.
        KMAGNETO: TODO: type description here.
        KIRIS: TODO: type description here.
        KIRISPROXY: TODO: type description here.
        KSCRIBE: TODO: type description here.
        KSTATS: TODO: type description here.
        KYODA: TODO: type description here.
        KALERTS: TODO: type description here.
        KKEYCHAIN: TODO: type description here.
        KLOGWATCHER: TODO: type description here.
        KSTATSCOLLECTER: TODO: type description here.
        KGANDALF: TODO: type description here.
        KNEXUS: TODO: type description here.
        KNEXUSPROXY: TODO: type description here.
        KSTORAGEPROXY: TODO: type description here.
        KTRICORDER: TODO: type description here.
        KRTCLIENT: TODO: type description here.
        KVAULTPROXY: TODO: type description here.
        KSMBPROXY: TODO: type description here.
        KBRIDGEPROXY: TODO: type description here.
        KLIBRARIAN: TODO: type description here.
        KGROOT: TODO: type description here.
        KEAGLEAGENT: TODO: type description here.
        KATHENA: TODO: type description here.
        KBIFROSTBROKER: TODO: type description here.
        KSMB2PROXY: TODO: type description here.
        KOS: TODO: type description here.
        KATOM: TODO: type description here.

    """

    KAPOLLO = 'kApollo'

    KBRIDGE = 'kBridge'

    KGENIE = 'kGenie'

    KGENIEGOFER = 'kGenieGofer'

    KMAGNETO = 'kMagneto'

    KIRIS = 'kIris'

    KIRISPROXY = 'kIrisProxy'

    KSCRIBE = 'kScribe'

    KSTATS = 'kStats'

    KYODA = 'kYoda'

    KALERTS = 'kAlerts'

    KKEYCHAIN = 'kKeychain'

    KLOGWATCHER = 'kLogWatcher'

    KSTATSCOLLECTER = 'kStatsCollecter'

    KGANDALF = 'kGandalf'

    KNEXUS = 'kNexus'

    KNEXUSPROXY = 'kNexusProxy'

    KSTORAGEPROXY = 'kStorageProxy'

    KTRICORDER = 'kTricorder'

    KRTCLIENT = 'kRtClient'

    KVAULTPROXY = 'kVaultProxy'

    KSMBPROXY = 'kSmbProxy'

    KBRIDGEPROXY = 'kBridgeProxy'

    KLIBRARIAN = 'kLibrarian'

    KGROOT = 'kGroot'

    KEAGLEAGENT = 'kEagleAgent'

    KATHENA = 'kAthena'

    KBIFROSTBROKER = 'kBifrostBroker'

    KSMB2PROXY = 'kSmb2Proxy'

    KOS = 'kOs'

    KATOM = 'kAtom'

==> cohesity_management_sdk-1.6.5.tar.gz: cohesity_management_sdk-1.6.5/cohesity_management_sdk/models/stopped_service_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2021 Cohesity Inc.

class StoppedServiceEnum(object):

    """Implementation of the 'StoppedService' enum.

    TODO: type enum description here.

    Attributes:
        KAPOLLO: TODO: type description here.
        KBRIDGE: TODO: type description here.
        KGENIE: TODO: type description here.
        KGENIEGOFER: TODO: type description here.
        KMAGNETO: TODO: type description here.
        KIRIS: TODO: type description here.
        KIRISPROXY: TODO: type description here.
        KSCRIBE: TODO: type description here.
        KSTATS: TODO: type description here.
        KYODA: TODO: type description here.
        KALERTS: TODO: type description here.
        KKEYCHAIN: TODO: type description here.
        KLOGWATCHER: TODO: type description here.
        KSTATSCOLLECTER: TODO: type description here.
        KGANDALF: TODO: type description here.
        KNEXUS: TODO: type description here.
        KNEXUSPROXY: TODO: type description here.
        KSTORAGEPROXY: TODO: type description here.
        KTRICORDER: TODO: type description here.
        KRTCLIENT: TODO: type description here.
        KVAULTPROXY: TODO: type description here.
        KSMBPROXY: TODO: type description here.
        KBRIDGEPROXY: TODO: type description here.
        KLIBRARIAN: TODO: type description here.
        KGROOT: TODO: type description here.
        KEAGLEAGENT: TODO: type description here.
        KATHENA: TODO: type description here.
        KBIFROSTBROKER: TODO: type description here.
        KSMB2PROXY: TODO: type description here.
        KOS: TODO: type description here.
        KATOM: TODO: type description here.
        KPATCH: TODO: type description here.
        KCOMPASS: TODO: type description here.

    """

    KAPOLLO = 'kApollo'

    KBRIDGE = 'kBridge'

    KGENIE = 'kGenie'

    KGENIEGOFER = 'kGenieGofer'

    KMAGNETO = 'kMagneto'

    KIRIS = 'kIris'

    KIRISPROXY = 'kIrisProxy'

    KSCRIBE = 'kScribe'

    KSTATS = 'kStats'

    KYODA = 'kYoda'

    KALERTS = 'kAlerts'

    KKEYCHAIN = 'kKeychain'

    KLOGWATCHER = 'kLogWatcher'

    KSTATSCOLLECTER = 'kStatsCollecter'

    KGANDALF = 'kGandalf'

    KNEXUS = 'kNexus'

    KNEXUSPROXY = 'kNexusProxy'

    KSTORAGEPROXY = 'kStorageProxy'

    KTRICORDER = 'kTricorder'

    KRTCLIENT = 'kRtClient'

    KVAULTPROXY = 'kVaultProxy'

    KSMBPROXY = 'kSmbProxy'

    KBRIDGEPROXY = 'kBridgeProxy'

    KLIBRARIAN = 'kLibrarian'

    KGROOT = 'kGroot'

    KEAGLEAGENT = 'kEagleAgent'

    KATHENA = 'kAthena'

    KBIFROSTBROKER = 'kBifrostBroker'

    KSMB2PROXY = 'kSmb2Proxy'

    KOS = 'kOs'

    KATOM = 'kAtom'

    KPATCH = 'kPatch'

    KCOMPASS = 'kCompass'
